Structs
Constants
- COUNTRY_
AND_ CODES - List of (alpha-2 code, country name) tuples based on ISO 3166-1 alpha-2.
- KNOWN_
REGION_ NAMES - List of non-country region names that were commented out above.
- NON_
STANDARD_ COUNTRY_ CODES - US_
STATE_ NAMES
Functions
- get_
country_ code - Gets the alpha-2 country code for a given country name. If the country name is not found in the standard or non-standard maps, it returns the country name as a fallback.
- is_
known_ country_ region - Utility function to check if a country name is in the standard list. Match U.S states to United States for consistency.